@@ -5,6 +5,8 @@ mod convenience;
 mod operations;
 mod params;
 mod plumbing;
+mod retryable;
+mod semaphores;
 mod sync;
 mod upload;
 
